# <img src='./logo.svg' card_color="#FF8600" width="50" style="vertical-align:bottom" style="vertical-align:bottom">Translation

## Summary

Translate phrases between languages.

## Description

Use this skill to translate individual words or sentences.

## Examples
- Translate hello to Polish.
- Translate thank you to Ukrainian.

## Contact Support

Use the [link](https://neongecko.com/ContactUs) or [submit an issue on GitHub](https://help.github.com/en/articles/creating-an-issue)

## Credits
[NeonDaniel](https://github.com/NeonDaniel)
[NeonGeckoCom](https://github.com/NeonGeckoCom)
[reginaneon](https://github.com/reginaneon)

## Tags
#NeonGecko Original
#NeonAI
